#
# spec file for package kweather
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  released
Name:           kweather
Version:        23.08.5
Release:        bp156.1.1
License:        GPL-2.0-or-later
Summary:        Weather application for Plasma
URL:            https://apps.kde.org/kweather
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KWeatherCore) >= 0.6.0
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5KirigamiAddons)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(Qt5Charts)
BuildRequires:  cmake(Qt5Core) >= 5.15.2
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickCompiler)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
Requires:       kirigami-addons
Requires:       kirigami2
Requires:       qt5qmlimport(QtCharts.2) >= 3

%description
A convergent weather application for Plasma. Has flat and dynamic/animated
views for showing forecasts and other information.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name

%files
%license LICENSES/*
%dir %{_kf5_plasmadir}/plasmoids
%dir %{_kf5_plugindir}/plasma/applets
%{_datadir}/dbus-1/services/org.kde.kweather.service
%{_kf5_applicationsdir}/org.kde.kweather.desktop
%{_kf5_appstreamdir}/org.kde.kweather.appdata.xml
%{_kf5_appstreamdir}/org.kde.plasma.kweather_1x4.appdata.xml
%{_kf5_bindir}/kweather
%{_kf5_iconsdir}/hicolor/scalable/apps/org.kde.kweather.svg
%{_kf5_plasmadir}/plasmoids/org.kde.plasma.kweather_1x4/
%{_kf5_plugindir}/plasma/applets/plasma_applet_kweather_1x4.so

%files lang -f %{name}.lang

%changelog
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 23.08.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.5/
- Changes since 23.08.4:
  * Switch to new CI format
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Adapt to plasma-framework moving to Plasma
  * CI: Comment out flatpak CI it uses some KF6 dependencies
  * Add snapcraft file to reuse.
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * flatpak: update runtime to 22.08
  * Fix syntax of dep5 copyright statements
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Fix binary stripping of APKs with Qt 5.15.10
  * Fix includes
  * Fix flat screenshot
  * Update screenshots
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Sat Jun 17 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add runtime dep on QtCharts QML module (boo#1212470)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Mon Mar 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Sat Feb 20 2021 Andrés B.S. <andresbs@opensuse.org>
- Added kweathercore as a requirement
